from __future__ import print_function  
from setuptools import setup, find_packages  
import sys  
  
setup(  
    name="test-page",
    version="0.1",
    author="wjolin",
    author_email="792994035@qq.com",
    description="this just a test for python pypi .",
    long_description=open("README").read(),
    license="MIT",
    url="",
    packages=["tidypage"],
    platforms=["any"],
    classifiers=[]
)
